==> qtjambi-webchannelquick-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiWebChannelQuick/QQmlWebChannel_shell.h <==
#ifndef QQMLWEBCHANNEL_SHELL_H
#define QQMLWEBCHANNEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebChannelQuick/qqmlwebchannel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambiQml/hashes.h>
#include <QtJambi/RegistryAPI>


class QQmlWebChannel_shell : public QQmlWebChannel, public QtJambiShellInterface
{
public:
    QQmlWebChannel_shell(QObject* parent0 = nullptr);
    ~QQmlWebChannel_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlWebChannel_access : public QQmlWebChannel
{
};

#endif // QQMLWEBCHANNEL_SHELL_H

==> qtjambi-webchannelquick-debuginfo-linux-x64-6.7.1.jar: sources/QtJambiWebChannelQuick/QQmlWebChannel_shell.h <==
#ifndef QQMLWEBCHANNEL_SHELL_H
#define QQMLWEBCHANNEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebChannelQuick/qqmlwebchannel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambiQml/hashes.h>
#include <QtJambi/RegistryAPI>


class QQmlWebChannel_shell : public QQmlWebChannel, public QtJambiShellInterface
{
public:
    QQmlWebChannel_shell(QObject* parent0 = nullptr);
    ~QQmlWebChannel_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQmlWebChannel_mshell;
    friend class QQmlWebChannel_oshell;
};


class QQmlWebChannel_mshell : public QQmlWebChannel_shell
{
public:
    using QQmlWebChannel_shell::QQmlWebChannel_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQmlWebChannel_oshell : public QQmlWebChannel_mshell
{
public:
    using QQmlWebChannel_mshell::QQmlWebChannel_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlWebChannel_access : public QQmlWebChannel
{
};

#endif // QQMLWEBCHANNEL_SHELL_H
